Installation
============

Release version
---------------

Installation is simple, just run::

    pip install --upgrade cavcalc

to install the latest release version of cavcalc.

Development version
-------------------

You can find the latest source code here: https://gitlab.com/sjrowlinson/cavcalc. If you wish to
use `cavcalc` as it is developed (getting access to new features and bug fixes before release), then
it is recommended to use the master branch as this should be consistently stable. Any changes on
branches other than master are not guaranteed to be stable and, therefore, it is not recommended to
use `cavcalc` from any of these potential branches. If you are unsure of which version to use then you
should install the release version of `cavcalc` to be on the safe side.

To clone this repository via SSH, simply do::

    git clone git@gitlab.com:sjrowlinson/cavcalc.git

Or via HTTPS::

    git clone https://gitlab.com/sjrowlinson/cavcalc.git

Then you can run::

    pip install -e .

in the root directory of your local copy of the `cavcalc` repository to install the package
in development mode.
